use std::time::Duration;

use crate::music::preview::Preview;
use crate::util::embed::Embed;
use lavalink_rs::client::LavalinkClient;
use serenity::all::{CommandInteraction, Context, GuildId};
use serenity::builder::{CreateCommand, CreateEmbed};

pub async fn run(ctx: &Context, command: &CommandInteraction, llc: &LavalinkClient) -> CreateEmbed {
    let username = command.user.name.as_str();

    let guild_id = match &command.guild_id {
        Some(guild_id) => guild_id,
        None => {
            return Embed::create_error_respose(
                username,
                "guild_id not found",
                "Could not find guild id.",
            );
        }
    };

    let Some(player_context) = llc.get_player_context(guild_id.get()) else {
        return Embed::create_error_respose(username, "Not playing", "There is no player context and therefore there is nothing playing.");
    };

    let Ok(player) = player_context.get_player().await else {
        return Embed::create_error_respose(username, "Can't get player", "Cannot get player from player context.");
    };


    if let Some(npt) = player.track {
        let npti = npt.info;
        let preview_data = Preview {
            title: npti.title,
            artist: Some(npti.author.to_string()),
            duration: Some(npti.length),
            thumbnail: npti.artwork_url,
            link: npti.uri
        };
        let position = Duration::from_millis(player_context.get_player().await.expect("Can't get player").state.position);
        
        return Embed::create_playing(preview_data, username, "Now playing")
        .await
        .field(
            "Position",
            format!(
                "{}min {}sec",
                position.as_secs() / 60,
                position.as_secs() % 60
            ),
            true
        );
    }
    
    return Embed::create_error_respose(username, "Not playing", "I'm currently not playing anything.");
}

pub fn register() -> CreateCommand {
    CreateCommand::new("nowplaying").description("Show what is currently playing.")
}
