use std::time::Duration;

use chrono::Local;
use serenity::all::{Color, CreateEmbed, CreateEmbedAuthor, CreateEmbedFooter};

use crate::music::preview::Preview;

pub struct Embed;

impl Embed {
    pub fn create_success_response(username: &str, title: &str, desc: &str) -> CreateEmbed {
        let current_time = Local::now().format("%Y-%m-%d @ %H:%M:%S");

        CreateEmbed::new()
            .title(title)
            .description(desc)
            .color(Color::from_rgb(224, 49, 26))
            .footer(CreateEmbedFooter::new(format!(
                "> {} - {}",
                current_time, username
            )))
    }

    pub fn create_error_respose(
        username: &str,
        error_title: &str,
        error_desc: &str,
    ) -> CreateEmbed {
        let current_time = Local::now().format("%Y-%m-%d @ %H:%M:%S");

        CreateEmbed::new()
            .author(CreateEmbedAuthor::new("Oops, something went wrong."))
            .title(error_title)
            .description(error_desc)
            .color(Color::from_rgb(224, 49, 26))
            .footer(CreateEmbedFooter::new(format!(
                "> {} - {}",
                current_time, username
            )))
    }

    pub async fn create_playing(
        preview: Preview,
        username: &str,
        show_as_author: &str,
    ) -> CreateEmbed {
        let current_time = Local::now().format("%Y-%m-%d @ %H:%M:%S");

        // Get metadata
        let title = preview.title;
        let artist = preview.artist.unwrap_or("t".to_string());
        let duration = Duration::from_millis(preview.duration.unwrap_or(0));
        let thumbnail = preview
            .thumbnail
            .unwrap_or("https://http.cat/images/403.jpg".to_string());
        let link = preview.link
            .unwrap_or("https://piped.moonleay.net/403".to_string());

        CreateEmbed::new()
            .author(CreateEmbedAuthor::new(show_as_author))
            .title(title)
            .url(link)
            .thumbnail(thumbnail)
            .field("Artist", artist, true)
            .field(
                "Duration",
                format!(
                    "{}min {}sec",
                    duration.as_secs() / 60,
                    duration.as_secs() % 60
                ),
                true,
            )
            .color(Color::from_rgb(81, 224, 26))
            .footer(CreateEmbedFooter::new(format!(
                "> {} - {}",
                current_time, username
            )))
    }
}
